@@ -8,6 +8,7 @@ import os
 import platform
 import shutil
 import sys
+import warnings
 from collections import defaultdict
 from functools import partial
 from pathlib import Path
@@ -64,7 +65,9 @@ def fetch_user_details(access_token, environment: ENVIRONMENTS) -> dict:
     endpoint = f"{ENVIRONMENTS_URLS[environment.value]['ORDS']}/userOrgDtls"
     try:
         logging.debug(f"Fetching user details {endpoint=}")
-        r = httpx.get(endpoint, headers={"Authorization": f"Bearer {access_token}"})
+        r = httpx.get(
+            endpoint, headers={"Authorization": f"Bearer {access_token}"}, timeout=10
+        )
         if not r.is_success:
             r.raise_for_status()
         result = r.json()
@@ -281,7 +284,9 @@ async def download_single_async(
             fh.write(r.content)
         if name and file_type == "fasta":
             update_fasta_header(
-                Path(f"{prefix}.{file_types_extensions[file_type]}"), guid, name
+                Path(out_dir) / Path(f"{prefix}.{file_types_extensions[file_type]}"),
+                guid,
+                name,
             )
     elif r.status_code == 400 and "API access" in r.json().get("message"):
         raise misc.AuthenticationError(
@@ -652,7 +657,9 @@ class Batch:
             f"{ENVIRONMENTS_URLS[self.environment.value]['ORDS']}/createSampleGuids"
         )
         logging.debug(f"Fetching guids; {endpoint=}")
-        r = httpx.post(url=endpoint, data=json.dumps(payload), headers=self.headers)
+        r = httpx.post(
+            url=endpoint, data=json.dumps(payload), headers=self.headers, timeout=120
+        )
         if not r.is_success:
             r.raise_for_status()
         result = r.json()
@@ -796,18 +803,20 @@ class Batch:
                     json_messages=self.json_messages,
                 )
         else:
-            process_map(
-                partial(
-                    misc.upload_sample,
-                    headers=self.headers,
-                    json_messages=self.json_messages,
-                ),
-                uploads,
-                max_workers=self.connections,
-                desc=f"Uploading {len(uploads)} sample(s)",
-                bar_format="{l_bar}{bar}| {n_fmt}/{total_fmt}",
-                leave=False,
-            )
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore")  # Suppress TqdmWarning about chunksize
+                process_map(
+                    partial(
+                        misc.upload_sample,
+                        headers=self.headers,
+                        json_messages=self.json_messages,
+                    ),
+                    uploads,
+                    max_workers=self.connections,
+                    desc=f"Uploading {len(uploads)} sample(s)",
+                    bar_format="{l_bar}{bar}| {n_fmt}/{total_fmt}",
+                    leave=False,
+                )
         self.uploaded = True
         if self.json_messages:
             misc.print_progress_message_json(action="upload", status="finished")
@@ -817,7 +826,7 @@ class Batch:
     def _finalise_submission(self):
         @retry(
             retry=retry_if_exception_type(httpx.HTTPError),
-            wait=wait_fixed(60),
+            wait=wait_fixed(30),
             stop=stop_after_attempt(2),
             before_sleep=before_sleep.before_sleep_log(logger, 10),
         )
@@ -829,7 +838,7 @@ class Batch:
                 url=endpoint,
                 data=json.dumps(submission, ensure_ascii=False).encode("utf-8"),
                 headers=headers,
-                timeout=80,
+                timeout=180,
             )
             logging.debug(f"post_submission(): {r.text=}")
             r.raise_for_status()
